==> cereeberus-0.1.3.tar.gz: cereeberus-0.1.3/README.md <==
# ceREEBerus

ceREEBerus is a Python package that allows you to perform various operations and analysis on Reeb graphs. The main goal of this package is to implement the available theoretical work on the Reeb graph interleaving distance and its variants for use in applied and machine learning contexts.

## Features

- Generate Reeb graphs from input data
- Visualize Reeb graphs in a clear and intuitive way
- Perform topological analysis on Reeb graphs
- Extract critical points and features from Reeb graphs
- Apply various algorithms and techniques to analyze Reeb graphs

## Installation

You can either update the latest version from pip using

```
pip install cereeberus
```

or to work with the most up to date version, you can clone the repo and install with

```{sh}
git clone git@github.com:MunchLab/ceREEBerus.git
cd ceREEBerus
pip install .
```

## Documentation

Find the documentation for ceREEBerus [here](https://munchlab.github.io/ceREEBerus/).

## Collaborators

The code is a compilation of work done by [Elizabeth Munch](http://www.elizabethmunch.com) with her research group and collaborators. The lead developer for this package is [Danielle Barnes](https://github.com/barnesd8), and other people who have contributed to ceREEBerus include:

- [Danielle Barnes](https://github.com/barnesd8)
- [Elena Wang](https://https://elenaxwang.com)
- [Ishika Ghsoh](https://www.ishikaghosh.com/)

## Contact Information

- [Liz Munch](http://www.elizabethmunch.com): [muncheli@msu.edu](mailto:muncheli@msu.edu)
- [Danielle Barnes](https://github.com/barnesd8): [barnesd8@msu.edu](mailto:barnesd8@msu.edu)

==> cereeberus-0.1.4.tar.gz: cereeberus-0.1.4/README.md <==
# ceREEBerus

ceREEBerus is a Python package that allows you to perform various operations and analysis on Reeb graphs. The main goal of this package is to implement the available theoretical work on the Reeb graph interleaving distance and its variants for use in applied and machine learning contexts.

## Features

- Generate Reeb graphs from input data
- Visualize Reeb graphs in a clear and intuitive way
- Perform topological analysis on Reeb graphs
- Extract critical points and features from Reeb graphs
- Apply various algorithms and techniques to analyze Reeb graphs

## Installation

You can either update the latest version from pip using

```
pip install cereeberus
```

or to work with the most up to date version, you can clone the repo and install with

```{sh}
git clone git@github.com:MunchLab/ceREEBerus.git
cd ceREEBerus
pip install .
```

## Documentation

Find the documentation for ceREEBerus [here](https://munchlab.github.io/ceREEBerus/).

## Collaborators

The code is a compilation of work done by [Elizabeth Munch](http://www.elizabethmunch.com) with her research group and collaborators. People who have contributed to ceREEBerus include:

- [Danielle Barnes](https://github.com/barnesd8)
- [Elena Wang](https://elenaxwang.com)
- [Ishika Ghsoh](https://www.ishikaghosh.com/)

## Contact Information

- [Liz Munch](http://www.elizabethmunch.com): [muncheli@msu.edu](mailto:muncheli@msu.edu)
- [Danielle Barnes](https://github.com/barnesd8): [barnesd8@msu.edu](mailto:barnesd8@msu.edu)
